/*
 *  
 *  $Id: herramientascore.h 4394 2011-11-11 09:45:22Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include "herramientaangulo.h"
#include "herramientapuntero.h"
#include "herramientaslider.h"
#include "herramientaregla.h"
#include "herramientaelevacion.h"
#include "herramientanota.h"
#include "herramientawindowlevel.h"
#include "herramientalupa.h"
#include "herramientamarcado.h"
#include "herramientarejillametrica.h"
#include "herramientaanotacionesesquina.h"
#include "herramientapaneltags.h"
#include "herramientareset.h"
#include "herramientalayoutventana.h"
#include "herramientadesencajar.h"
#include "herramientadeshacer.h"
#include "herramientainterpolate.h"
